# Generated by Django 2.2.8 on 2019-12-08 17:31

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0053_auto_20191208_1001'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_item',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_locations',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='planing_operation_loc', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_material',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='planing_operation', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_refs',
            name='income',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='operation_income', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_refs',
            name='outcome',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='operation_outcome', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_resources',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='planing_operation_res', to='planing.Operations'),
        ),
        migrations.AlterField(
            model_name='operation_standard_prod',
            name='operation',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='planing.Operations'),
        ),
    ]



# Generated by Django 3.0.3 on 2020-02-06 15:40

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0130_auto_20200206_1526'),
        ('ckk', '0191_auto_20200206_1206'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item_image_refs',
            name='thumb',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='kd.Documents_thumb'),
        ),
        migrations.AlterField(
            model_name='item_image_refs',
            name='thumb10',
            field=isc_common.fields.related.ForeignKeyCascade(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='kd.Documents_thumb10'),
        ),
    ]



# Generated by Django 2.2.3 on 2019-07-14 08:52

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0057_pathes_prefix'),
    ]

    operations = [
        migrations.AlterField(
            model_name='uploades',
            name='path',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='kd.Pathes'),
        ),
    ]



# Generated by Django 2.2.2 on 2019-06-10 00:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0041_auto_20190609_1918'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='document_attr_cross',
            unique_together=set(),
        ),
    ]



from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
from isc_common.http.RPCResponse import RPCResponseConstant
from isc_common.http.response import JsonResponse
from kaf_pas.ckk.models.material_askon import Material_askon
from kaf_pas.ckk.models.material_askon_mview import Material_askon_mview, Material_askon_mviewManager


@JsonResponseWithException()
def Material_askon_Fetch(request):
    return JsonResponse(
        DSResponse(
            request=request,
            data=Material_askon_mview.objects.
                filter().
                get_range_rows1(
                request=request,
                function=Material_askon_mviewManager.getRecord
            ),
            status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Material_askon_Add(request):
    return JsonResponse(DSResponseAdd(data=Material_askon.objects.createFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Material_askon_Update(request):
    return JsonResponse(DSResponseUpdate(data=Material_askon.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Material_askon_Remove(request):
    return JsonResponse(DSResponse(request=request, data=Material_askon.objects.deleteFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Material_askon_Lookup(request):
    return JsonResponse(DSResponse(request=request, data=Material_askon.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Material_askon_Info(request):
    return JsonResponse(DSResponse(request=request, data=Material_askon.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Material_askon_Copy(request):
    return JsonResponse(DSResponse(request=request, data=Material_askon.objects.copyFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)



import logging

from bitfield import BitField

from isc_common.fields.related import ForeignKeyCascade
from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
from kaf_pas.planing.models.levels import Levels
from kaf_pas.planing.models.operations import Operations
from kaf_pas.planing.models.sections import Sections

logger = logging.getLogger(__name__)


class Operation_sectionQuerySet(AuditQuerySet):
    pass


class Operation_sectionManager(AuditManager):

    @staticmethod
    def props():
        return BitField(flags=(
            ('isProductionOrder', 'Уровень заказа на производство'),  # 1
        ), default=0, db_index=True)

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'editing': record.editing,
            'deliting': record.deliting,
        }
        return res

    def get_queryset(self):
        return Operation_sectionQuerySet(self.model, using=self._db)


class Operation_section(AuditModel):
    operation = ForeignKeyCascade(Operations)
    section = ForeignKeyCascade(Sections)


    objects = Operation_sectionManager()

    def __str__(self):
        return f"ID:{self.id}, section: [{self.section}] , operation: [{self.operation}]"

    def __repr__(self):
        return self.__str__()

    class Meta:
        verbose_name = 'Кросс-таблица'
        unique_together = (('operation', 'section'),)



import logging

from django.db.models import TextField, PositiveIntegerField

from isc_common.fields.code_field import CodeField
from isc_common.fields.related import ForeignKeyProtect, ForeignKeyCascade
from isc_common.managers.common_managet_with_lookup_fields import CommonManagetWithLookUpFieldsManager
from isc_common.models.audit import AuditModel
from kaf_pas.ckk.models.attr_type import Attr_type
from kaf_pas.kd.models.document_attributes import Document_attributesQuerySet
from kaf_pas.kd.models.documents import Documents

logger = logging.getLogger(__name__)


class Document_attributes_viewManager(CommonManagetWithLookUpFieldsManager):

    def get_queryset(self):
        return Document_attributesQuerySet(self.model, using=self._db)

    @staticmethod
    def getRecord(record):
        res = {
            "id": record.id,
            "attr_type_id": record.attr_type.id,
            "attr_type__code": record.attr_type.code,
            "attr_type__name": record.attr_type.name,
            "attr_type__description": record.attr_type.description if record.attr_type else None,
            "value_str": record.value_str,
            "value_int": record.value_int,
            "lastmodified": record.lastmodified,
            "editing": record.editing,
            "deliting": record.deliting,
        }
        return res


class Document_attributes_view(AuditModel):
    document = ForeignKeyCascade(Documents, verbose_name='Документ')
    attr_type = ForeignKeyProtect(Attr_type, verbose_name='Тип атрибута')
    value_str = TextField(verbose_name="Значение атрибута", db_index=True)
    value_int = PositiveIntegerField(verbose_name="Значение атрибута", db_index=True)
    section = CodeField(verbose_name="Раздел", null=True, blank=True)
    subsection = CodeField(verbose_name="Подраздел", null=True, blank=True)
    position_in_document = PositiveIntegerField()

    def __str__(self):
        return self.value_str

    class Meta:
        verbose_name = 'Аттрибуты докуменнта'
        managed = False
        db_table = 'kd_document_attrs_view'



# Generated by Django 2.2.1 on 2019-05-17 17:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('capacity', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='resources',
            name='type',
        ),
        migrations.DeleteModel(
            name='Resources_type',
        ),
    ]



from django.urls import path

from kaf_pas.planing.views import operation_value

urlpatterns = [

    path('Operation_value/Fetch/', operation_value.Operation_value_Fetch),
    path('Operation_value/Add', operation_value.Operation_value_Add),
    path('Operation_value/Update', operation_value.Operation_value_Update),
    path('Operation_value/Remove', operation_value.Operation_value_Remove),
    path('Operation_value/Lookup/', operation_value.Operation_value_Lookup),
    path('Operation_value/Info/', operation_value.Operation_value_Info),
    path('Operation_value/Copy', operation_value.Operation_value_Copy),

]



import logging

from django.db import transaction
from isc_common.http.DSRequest import DSRequest
from isc_common.http.RPCResponse import RPCResponseConstant

from kaf_pas.ckk.models.item_refs import Item_refs

logger = logging.getLogger(__name__)

class CopyItems(DSRequest):
    def __init__(self, request):
        DSRequest.__init__(self, request)
        data = self.get_data()

        source = data.get('source')
        desctination = data.get('destination')

        with transaction.atomic():
            Item_refs.objects.filter(id=desctination).select_for_update()
            if isinstance(source, list):
                for src in source:
                    Item_refs.objects.filter(id=src).select_for_update()
                    Item_refs.objects.create(parent_id=desctination, child_id=src)
                    Item_refs.objects.filter(parent__isnull=True, child_id=src).delete()

        self.response = dict(status=RPCResponseConstant.statusSuccess)



import logging

from isc_common.auth.managers.user_manager import UserManager
from isc_common.auth.models.user import User
from isc_common.number import DelProps

logger = logging.getLogger(__name__)


class Users_exManager(UserManager):

    @staticmethod
    def getRecord(record):
        res = {
            "id": record.id,
            "username": record.username,
            "description": record.description,
            "first_name": record.first_name,
            "last_name": record.last_name,
            "email": record.email,
            "middle_name": record.middle_name,
            "short_name": record.get_short_name,
            "short_name1": record.get_short_name1,
            "password": record.password,
            "last_login": record.last_login,
            "lastmodified": record.lastmodified,
            "location_position": record.location_position,
            "editing": record.editing,
            "deliting": record.deliting,
            "color": record.color,
            "bot": User.props.bot,
        }
        return DelProps(res)


class Users_ex(User):
    objects = Users_exManager()

    @property
    def location_position(self):
        from kaf_pas.input.models.user_add_info import User_add_info
        res = []
        for item in User_add_info.objects.filter(user=self.id):
            res.append(f'{item.location.full_name} : {item.position.name}')
        return ', '.join(res)

    def __str__(self):
        return f'ID:{self.id}'

    def __repr__(self):
        return self.__str__()

    class Meta:
        verbose_name = 'Пользователи с должностями'
        proxy = True



from django.urls import path

from kaf_pas.production.views import launch_operations_material

urlpatterns = [

    path('Launch_operations_material/Fetch/', launch_operations_material.Launch_operations_material_Fetch),
    path('Launch_operations_material/Add', launch_operations_material.Launch_operations_material_Add),
    path('Launch_operations_material/Update', launch_operations_material.Launch_operations_material_Update),
    path('Launch_operations_material/Remove', launch_operations_material.Launch_operations_material_Remove),
    path('Launch_operations_material/Lookup/', launch_operations_material.Launch_operations_material_Lookup),
    path('Launch_operations_material/Info/', launch_operations_material.Launch_operations_material_Info),
    path('Launch_operations_material/Copy', launch_operations_material.Launch_operations_material_Copy),

]



# Generated by Django 3.0.3 on 2020-02-23 15:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0204_auto_20200223_1524'),
    ]

    operations = [
        migrations.AlterField(
            model_name='launch_item_refs',
            name='qty',
            field=models.FloatField(blank=True, null=True),
        ),
    ]



from django.urls import path

from kaf_pas.kd.views import documents_history

urlpatterns = [

    path('Documents_history/Fetch/', documents_history.Documents_history_Fetch),
    path('Documents_history/Add', documents_history.Documents_history_Add),
    path('Documents_history/Update', documents_history.Documents_history_Update),
    path('Documents_history/Remove', documents_history.Documents_history_Remove),
    path('Documents_history/Lookup/', documents_history.Documents_history_Lookup),
    path('Documents_history/Info/', documents_history.Documents_history_Info),
    path('Documents_history/Copy', documents_history.Documents_history_Copy),

]



from django.urls import path

from kaf_pas.kd.views import document_attributes_Name_sortament

urlpatterns = [

    path('Document_attributes_Name_sortament/Fetch/', document_attributes_Name_sortament.Document_attributes_Name_sortament_Fetch),
    path('Document_attributes_Name_sortament/Add', document_attributes_Name_sortament.Document_attributes_Name_sortament_Add),
    path('Document_attributes_Name_sortament/Update', document_attributes_Name_sortament.Document_attributes_Name_sortament_Update),
    path('Document_attributes_Name_sortament/Remove', document_attributes_Name_sortament.Document_attributes_Name_sortament_Remove),
    path('Document_attributes_Name_sortament/Lookup/', document_attributes_Name_sortament.Document_attributes_Name_sortament_Lookup),
    path('Document_attributes_Name_sortament/Info/', document_attributes_Name_sortament.Document_attributes_Name_sortament_Info),
    path('Document_attributes_Name_sortament/Copy', document_attributes_Name_sortament.Document_attributes_Name_sortament_Copy),

]



# Generated by Django 2.2.6 on 2019-10-14 15:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0156_auto_20191014_0942'),
    ]

    operations = [
        migrations.AddField(
            model_name='item_line',
            name='section_num',
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]



import logging

from django.db.models import TextField

from isc_common.fields.related import ForeignKeyProtect
from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
from kaf_pas.kd.models.lotsman_documents_hierarcy import Lotsman_documents_hierarcy

logger = logging.getLogger(__name__)


class Lotsman_documents_hierarcy_filesQuerySet(AuditQuerySet):
    pass


class Lotsman_documents_hierarcy_filesManager(AuditManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'editing': record.editing,
            'deliting': record.deliting,
        }
        return res

    def get_queryset(self):
        return Lotsman_documents_hierarcy_filesQuerySet(self.model, using=self._db)


class Lotsman_documents_hierarcy_files(AuditModel):
    lotsman_document = ForeignKeyProtect(Lotsman_documents_hierarcy)
    path = TextField()

    objects = Lotsman_documents_hierarcy_filesManager()

    def __str__(self):
        return f'ID:{self.id}'

    def __repr__(self):
        return self.__str__()

    class Meta:
        verbose_name = 'Файлы обрабатанные для данной позиции'
        unique_together = (('lotsman_document', 'path'),)



import logging

from django.core.management import BaseCommand

from kaf_pas.kd.models.documents import DocumentManager

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = "Тестирование get_m_view"

    def handle(self, *args, **options):
        logger.info(self.help)

        DocumentManager.get_m_view()



# Generated by Django 3.0.5 on 2020-04-13 14:50

import bitfield.models
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0220_auto_20200330_1356'),
    ]

    operations = [
        migrations.CreateModel(
            name='Item_qty',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('qty', models.PositiveIntegerField()),
                ('props', bitfield.models.BitField((('items', 'Состав изделия'), ('teach', 'Технологическая спецификация')), db_index=True, default=1)),
                ('child', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='Item_qty_child', to='ckk.Item')),
                ('parent', isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Item_qty_parent', to='ckk.Item')),
            ],
            options={
                'verbose_name': 'Количество элементов',
            },
        ),
    ]



# Generated by Django 3.0.4 on 2020-03-05 17:29

import bitfield.models
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0124_operation_value_props'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Production_order_values',
        ),
        migrations.CreateModel(
            name='Production_order_detail',
            fields=[
            ],
            options={
                'verbose_name': 'Заказы на производство',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('planing.operations_view',),
        ),
        migrations.AlterField(
            model_name='operation_value',
            name='props',
            field=bitfield.models.BitField((('perone', 'Из расчета на еденицу продукции'), ('used_in_release', 'Учавствовало в учете выпуска')), db_index=True, default=0),
        ),
        migrations.CreateModel(
            name='Production_order_values',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('date', models.DateTimeField(default=None)),
            ],
            options={
                'verbose_name': 'Списания',
                'db_table': 'planing_operations_values_view',
                'managed': False,
            },
        ),
    ]



# Generated by Django 2.2.1 on 2019-05-21 15:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0050_auto_20190521_1517'),
    ]

    operations = [
        # migrations.RemoveField(
        #     model_name='status',
        #     name='id_owner',
        # ),
    ]



# Generated by Django 2.2.1 on 2019-05-21 15:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0049_auto_20190521_1236'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='status',
            # unique_together={('id_owner', 'code_owner', 'code')},
            unique_together={('code_owner', 'code')},
        ),
        migrations.RemoveField(
            model_name='status',
            name='name_owner',
        ),
    ]



from django.urls import path

from kaf_pas.production.views import resource_users

urlpatterns = [

    path('Resource_users/Fetch/', resource_users.Resource_users_Fetch),
    path('Resource_users/Add', resource_users.Resource_users_Add),
    path('Resource_users/Update', resource_users.Resource_users_Update),
    path('Resource_users/Remove', resource_users.Resource_users_Remove),
    path('Resource_users/Lookup/', resource_users.Resource_users_Lookup),
    path('Resource_users/Info/', resource_users.Resource_users_Info),
    path('Resource_users/Copy', resource_users.Resource_users_Copy),

]



# Generated by Django 2.2.8 on 2019-12-07 13:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('planing', '0036_operation_launch_operation_material'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='launch_item_refs_timing',
            name='ed_izm',
        ),
        migrations.RemoveField(
            model_name='launch_item_refs_timing',
            name='launch_item_refs',
        ),
        migrations.DeleteModel(
            name='Launch_item_timing_view',
        ),
        migrations.DeleteModel(
            name='Launch_item_refs_timing',
        ),
    ]



# Generated by Django 2.2.8 on 2019-12-26 06:27

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('system', '0007_auto_20191225_2034'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contants',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(unique=True),
        ),
    ]



# Generated by Django 2.2.6 on 2019-10-08 12:58

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0069_auto_20191008_1257'),
    ]

    operations = [
        migrations.AlterField(
            model_name='operation_material',
            name='operation_item',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Operations_item'),
        ),
        migrations.AlterField(
            model_name='operation_resources',
            name='operation_item',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='production.Operations_item'),
        ),
    ]



import logging

from isc_common.fields.code_field import ColorField
from isc_common.fields.related import ForeignKeyCascade, ForeignKeyProtect
from isc_common.models.audit import AuditModel, AuditManager, AuditQuerySet
from isc_common.models.standard_colors import Standard_colors
from kaf_pas.planing.models.operations import Operations

logger = logging.getLogger(__name__)


class Operation_colorQuerySet(AuditQuerySet):
    pass


class Operation_colorManager(AuditManager):

    @staticmethod
    def getRecord(record):
        res = {
            'id': record.id,
            'editing': record.editing,
            'deliting': record.deliting,
            'color_id': record.color.id,
            'color__color': record.color.color,
            'color__name': record.color.name,
        }
        return res

    def get_queryset(self):
        return Operation_colorQuerySet(self.model, using=self._db)


class Operation_color(AuditModel):
    operation = ForeignKeyCascade(Operations)
    color = ForeignKeyProtect(Standard_colors)

    objects = Operation_colorManager()

    def __str__(self):
        return f"ID:{self.id}"

    def __repr__(self):
        return self.__str__()

    class Meta:
        verbose_name = 'Кросс таблица значений операции'
        unique_together =(('operation','color'),)



# Generated by Django 3.0.3 on 2020-02-11 08:11

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0135_auto_20200208_1422'),
    ]

    operations = [
        migrations.AddField(
            model_name='lotsman_document_attr_cross',
            name='parent_document',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, related_name='Lotsman_document_attr_cross_parent_doc', to='kd.Lotsman_documents_hierarcy'),
        ),
        migrations.AlterField(
            model_name='lotsman_document_attr_cross',
            name='document',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, related_name='Lotsman_document_attr_cross_doc', to='kd.Lotsman_documents_hierarcy'),
        ),
    ]



from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException, JsonWSResponseWithException
from isc_common.http.RPCResponse import RPCResponseConstant
from isc_common.http.response import JsonResponse
from kaf_pas.planing.models.operation_launches import Operation_launches, Operation_launchesManager


@JsonResponseWithException()
def Operation_launches_Fetch(request):
    return JsonResponse(
        DSResponse(
            request=request,
            data=Operation_launches.objects.
                filter().
                get_range_rows1(
                request=request,
                function=Operation_launchesManager.getRecord
            ),
            status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operation_launches_Add(request):
    return JsonResponse(DSResponseAdd(data=Operation_launches.objects.createFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operation_launches_Update(request):
    return JsonResponse(DSResponseUpdate(data=Operation_launches.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)


@JsonWSResponseWithException()
def Operation_launches_ReCalcRoutes(request):
    return JsonResponse(DSResponseUpdate(data=Operation_launches.objects.reCalcRoutesFromRequest(request), status=RPCResponseConstant.statusSuccess).response)

@JsonWSResponseWithException()
def Operation_launches_MakeProdOrder(request):
    return JsonResponse(DSResponseUpdate(data=Operation_launches.objects.makeProdOrderFromRequest(request), status=RPCResponseConstant.statusSuccess).response)\

@JsonWSResponseWithException()
def Operation_launches_DeleteProdOrder(request):
    return JsonResponse(DSResponseUpdate(data=Operation_launches.objects.deleteProdOrderFromRequest(request), status=RPCResponseConstant.statusSuccess).response)

@JsonWSResponseWithException()
def Operation_launches_CleanRoutes(request):
    return JsonResponse(DSResponseUpdate(data=Operation_launches.objects.cleanRoutesFromRequest(request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operation_launches_Remove(request):
    return JsonResponse(DSResponse(request=request, data=Operation_launches.objects.deleteFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operation_launches_Lookup(request):
    return JsonResponse(DSResponse(request=request, data=Operation_launches.objects.lookupFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operation_launches_Info(request):
    return JsonResponse(DSResponse(request=request, data=Operation_launches.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)


@JsonResponseWithException()
def Operation_launches_Copy(request):
    return JsonResponse(DSResponse(request=request, data=Operation_launches.objects.copyFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)



# Generated by Django 2.2.2 on 2019-06-06 09:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0076_auto_20190606_0920'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Item_production_specificationView',
        ),
    ]



from django.urls import path

from kaf_pas.kd.views import document_attributes_SPC_CLM_NOTE

urlpatterns = [

    path('Document_attributes_SPC_CLM_NOTE/Fetch/', document_attributes_SPC_CLM_NOTE.Document_attributes_SPC_CLM_NOTE_Fetch),
    path('Document_attributes_SPC_CLM_NOTE/Add', document_attributes_SPC_CLM_NOTE.Document_attributes_SPC_CLM_NOTE_Add),
    path('Document_attributes_SPC_CLM_NOTE/Update', document_attributes_SPC_CLM_NOTE.Document_attributes_SPC_CLM_NOTE_Update),
    path('Document_attributes_SPC_CLM_NOTE/Remove', document_attributes_SPC_CLM_NOTE.Document_attributes_SPC_CLM_NOTE_Remove),
    path('Document_attributes_SPC_CLM_NOTE/Lookup/', document_attributes_SPC_CLM_NOTE.Document_attributes_SPC_CLM_NOTE_Lookup),
    path('Document_attributes_SPC_CLM_NOTE/Info/', document_attributes_SPC_CLM_NOTE.Document_attributes_SPC_CLM_NOTE_Info),
    path('Document_attributes_SPC_CLM_NOTE/Copy', document_attributes_SPC_CLM_NOTE.Document_attributes_SPC_CLM_NOTE_Copy),

]



import logging

from django.core.management import BaseCommand

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    def handle(self, *args, **options):
        from kaf_pas.planing.models.operations import OperationsManager
        OperationsManager.make_production_order(dict(user=2, id=17))



import logging

from django.db import transaction

from isc_common.http.DSRequest import DSRequest
from isc_common.http.RPCResponse import RPCResponseConstant
from kaf_pas.ckk.models.item import Item
from kaf_pas.ckk.models.item_image_refs import Item_image_refs
from kaf_pas.ckk.models.item_line import Item_line
from kaf_pas.ckk.models.item_location import Item_location
from kaf_pas.ckk.models.item_refs import Item_refs
from kaf_pas.production.models.launch_item_line import Launch_item_line
from kaf_pas.production.models.launch_item_refs import Launch_item_refs
from kaf_pas.production.models.launch_operations_item import Launch_operations_item
from kaf_pas.production.models.operations_item import Operations_item
from kaf_pas.production.models.ready_2_launch_detail import Ready_2_launch_detail
from kaf_pas.sales.models.precent_items import Precent_items

logger = logging.getLogger(__name__)


class CombineItems(DSRequest):
    @staticmethod
    def combine(recordTarget, recordsSource):
        def exec(loger_func=lambda x: bool):
            with transaction.atomic():
                try:
                    loger_func()
                    return True
                except Exception as ex:
                    logger.debug(ex)
                    return False

        for recordSource in recordsSource:
            if recordSource.get('id') != recordTarget.get('id'):
                for item_refs in Item_refs.objects.filter(child_id=recordSource.get('id')):
                    item_refs.child_id = recordTarget.get('id')
                    if not exec(item_refs.save):
                        item_refs.delete()

                for item_refs in Item_refs.objects.filter(parent_id=recordSource.get('id')):
                    item_refs.parent_id = recordTarget.get('id')
                    if not exec(item_refs.save):
                        item_refs.delete()

                for item_image_refs in Item_image_refs.objects.filter(item_id=recordSource.get('id')):
                    item_image_refs.item_id = recordTarget.get('id')
                    if not exec(item_image_refs.save):
                        item_image_refs.delete()

                for item_line in Item_line.objects.filter(child_id=recordSource.get('id')):
                    item_line.child_id = recordTarget.get('id')
                    if not exec(item_line.save):
                        item_line.delete()

                for item_line in Item_line.objects.filter(parent_id=recordSource.get('id')):
                    item_line.parent_id = recordTarget.get('id')
                    if not exec(item_line.save):
                        item_line.delete()

                for item_location in Item_location.objects.filter(item_id=recordSource.get('id')):
                    item_location.item_id = recordTarget.get('id')
                    if not exec(item_location.save):
                        item_location.delete()

                for operations_item in Operations_item.objects.filter(item_id=recordSource.get('id')):
                    operations_item.item_id = recordTarget.get('id')
                    if not exec(operations_item.save):
                        operations_item.delete()

                for launch_operations_item in Precent_items.objects.filter(item_id=recordSource.get('id')):
                    launch_operations_item.item_id = recordTarget.get('id')
                    if not exec(launch_operations_item.save):
                        launch_operations_item.delete()

                for item_refs in Launch_item_refs.objects.filter(child_id=recordSource.get('id')):
                    item_refs.child_id = recordTarget.get('id')
                    if not exec(item_refs.save):
                        item_refs.delete()

                for item_refs in Launch_item_refs.objects.filter(parent_id=recordSource.get('id')):
                    item_refs.parent_id = recordTarget.get('id')
                    if not exec(item_refs.save):
                        item_refs.delete()

                for item_line in Launch_item_line.objects.filter(child_id=recordSource.get('id')):
                    item_line.child_id = recordTarget.get('id')
                    if not exec(item_line.save):
                        item_line.delete()

                for item_line in Launch_item_line.objects.filter(parent_id=recordSource.get('id')):
                    item_line.parent_id = recordTarget.get('id')
                    if not exec(item_line.save):
                        item_line.delete()

                for launch_operations_item in Launch_operations_item.objects.filter(item_id=recordSource.get('id')):
                    launch_operations_item.item_id = recordTarget.get('id')
                    if not exec(launch_operations_item.save):
                        launch_operations_item.delete()

                # for ready_2_launch_detail in Ready_2_launch_detail.objects.filter(item_id=recordSource.get('id')):
                #     ready_2_launch_detail.item_id = recordTarget.get('id')
                #     if not exec(ready_2_launch_detail.save):
                #         ready_2_launch_detail.delete()

                Item.objects.filter(id=recordSource.get('id')).delete()

    def __init__(self, request):
        DSRequest.__init__(self, request)
        data = self.get_data()

        recordTarget = data.get('recordTarget')
        if not isinstance(recordTarget, dict):
            raise Exception(f'recordTarget must be a dict')

        recordsSource = data.get('recordsSource')
        if not isinstance(recordsSource, list):
            raise Exception(f'recordsSource must be a list')

        # with transaction.atomic():
        CombineItems.combine(recordsSource=recordsSource, recordTarget=recordTarget)

        self.response = dict(status=RPCResponseConstant.statusSuccess)



# Generated by Django 2.2.1 on 2019-05-25 13:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0028_auto_20190525_0954'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document_attrs',
            name='value_str',
            field=models.TextField(db_index=True, verbose_name='Значение атрибута'),
        ),
    ]



# Generated by Django 2.2 on 2019-04-25 18:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0005_auto_20190425_1808'),
    ]

    operations = [
        migrations.RenameField(
            model_name='operation_plan_templates_item_lines',
            old_name='itemLine',
            new_name='item_line',
        ),
    ]



# Generated by Django 2.2.8 on 2019-12-13 13:22

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0091_auto_20191213_1307'),
    ]

    operations = [
        migrations.AddField(
            model_name='lotsman_documents',
            name='upload',
            field=isc_common.fields.related.ForeignKeyCascade(default=None, on_delete=django.db.models.deletion.CASCADE, to='kd.Uploades'),
        ),
        migrations.AlterField(
            model_name='lotsman_documents_attributes',
            name='document',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='kd.Lotsman_documents'),
        ),
    ]



# Generated by Django 2.2.1 on 2019-05-16 23:22

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0043_auto_20190521_1853'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='STMP_1',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='STMP_1', to='kd.Document_attrs', verbose_name='Наименование изделия'),
        ),
        migrations.AlterField(
            model_name='item',
            name='STMP_2',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='STMP_2', to='kd.Document_attrs', verbose_name='Обозначение изделия'),
        ),
    ]



import logging

from bitfield import BitField
from crypto.models.crypto_file import Crypto_file
from django.db.models import DateTimeField

logger = logging.getLogger(__name__)


class Files_askon(Crypto_file):
    file_modification_time = DateTimeField(verbose_name='Дата время поcледнего модификации документа')
    props = BitField(flags=(('imp', 'Импорт'),), db_index=True)

    def __str__(self):
        return f"{self.id}"

    class Meta:
        verbose_name = 'Файлы АСКОНа'



# Generated by Django 3.0.3 on 2020-03-02 05:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('production', '0227_auto_20200302_0422'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='launch_item_line',
            name='SPC_CLM_COUNT_PER_ONE',
        ),
    ]



# Generated by Django 2.2.1 on 2019-05-29 10:22

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0068_auto_20190529_0628'),
    ]

    operations = [
        migrations.AddField(
            model_name='materials',
            name='material_1C',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='one_c.Documents_param_1c'),
        ),
    ]



# Generated by Django 3.0.3 on 2020-02-11 08:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0137_auto_20200211_0811'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='lotsman_document_attr_cross',
            unique_together={('document', 'parent_document', 'attribute')},
        ),
    ]



# Generated by Django 2.2.3 on 2019-07-08 15:44

from django.db import migrations
import isc_common.fields.code_field


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0128_auto_20190707_2035'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ed_izm',
            name='code',
            field=isc_common.fields.code_field.CodeStrictField(unique=True),
        ),
    ]



# Generated by Django 2.2.7 on 2019-11-19 07:26

from django.db import migrations
import django.db.models.deletion
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0158_delete_status'),
        ('production', '0112_auto_20191118_2128'),
    ]

    operations = [
        migrations.AddField(
            model_name='launch_item_line',
            name='added_parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='Launch_item_added_parent', to='ckk.Item'),
        ),
        migrations.AlterField(
            model_name='launch_item_line',
            name='child',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='Launch_item_child', to='ckk.Item'),
        ),
        migrations.AlterField(
            model_name='launch_item_line',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, related_name='Launch_item_parent', to='ckk.Item'),
        ),
    ]



# Generated by Django 3.0.3 on 2020-02-27 21:36

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('ckk', '0212_auto_20200225_1013'),
        ('production', '0218_auto_20200227_1632'),
    ]

    operations = [
        migrations.CreateModel(
            name='Operations_template_material',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('qty', models.DecimalField(decimal_places=4, default=0.0, max_digits=10)),
            ],
            options={
                'verbose_name': 'Кросс таблица',
            },
        ),
        migrations.CreateModel(
            name='Operations_template_resource',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('batch_size', models.PositiveIntegerField(default=1)),
            ],
            options={
                'verbose_name': 'Кросс таблица',
            },
        ),
        migrations.AddField(
            model_name='operations_template_resource',
            name='location',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Locations'),
        ),
        migrations.AddField(
            model_name='operations_template_resource',
            name='resource',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Resource'),
        ),
        migrations.AddField(
            model_name='operations_template_resource',
            name='template',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='production.Operations_template_detail'),
        ),
        migrations.AddField(
            model_name='operations_template_material',
            name='edizm',
            field=isc_common.fields.related.ForeignKeyProtect(default=None, on_delete=django.db.models.deletion.PROTECT, to='ckk.Ed_izm'),
        ),
        migrations.AddField(
            model_name='operations_template_material',
            name='material',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Materials'),
        ),
        migrations.AddField(
            model_name='operations_template_material',
            name='material_askon',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='ckk.Material_askon'),
        ),
        migrations.AddField(
            model_name='operations_template_material',
            name='parent',
            field=isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='production.Operations_template_material'),
        ),
        migrations.AddField(
            model_name='operations_template_material',
            name='template',
            field=isc_common.fields.related.ForeignKeyCascade(on_delete=django.db.models.deletion.CASCADE, to='production.Operations_template_detail'),
        ),
        migrations.AddConstraint(
            model_name='operations_template_resource',
            constraint=models.UniqueConstraint(condition=models.Q(('location', None), ('resource', None)), fields=('template',), name='Operations_template_resource_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='operations_template_resource',
            constraint=models.UniqueConstraint(condition=models.Q(location=None), fields=('template', 'resource'), name='Operations_template_resource_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='operations_template_resource',
            constraint=models.UniqueConstraint(condition=models.Q(resource=None), fields=('location', 'template'), name='Operations_template_resource_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='operations_template_resource',
            constraint=models.UniqueConstraint(fields=('location', 'template', 'resource'), name='Operations_template_resource_unique_constraint_3'),
        ),
        migrations.AddConstraint(
            model_name='operations_template_material',
            constraint=models.UniqueConstraint(condition=models.Q(('material', None), ('material_askon', None)), fields=('template',), name='Operations_template_material_unique_constraint_0'),
        ),
        migrations.AddConstraint(
            model_name='operations_template_material',
            constraint=models.UniqueConstraint(condition=models.Q(material_askon=None), fields=('material', 'template'), name='Operations_template_material_unique_constraint_1'),
        ),
        migrations.AddConstraint(
            model_name='operations_template_material',
            constraint=models.UniqueConstraint(condition=models.Q(material=None), fields=('material_askon', 'template'), name='Operations_template_material_unique_constraint_2'),
        ),
        migrations.AddConstraint(
            model_name='operations_template_material',
            constraint=models.UniqueConstraint(fields=('material', 'material_askon', 'template'), name='Operations_template_material_unique_constraint_3'),
        ),
    ]



# Generated by Django 2.2 on 2019-04-17 18:21

import bitfield.models
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import isc_common.fields.related


class Migration(migrations.Migration):

    dependencies = [
        ('kd', '0020_cdw_attrs_spw_attrs'),
        ('ckk', '0024_auto_20190417_0107'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='props',
            field=bitfield.models.BitField((('relevant', 'Актуальность'), ('from_cdw', 'Получено из чертежа')), default=1),
        ),
        migrations.CreateModel(
            name='Item_image_refs',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='Идентификатор')),
                ('id_old', models.BigIntegerField(blank=True, null=True, verbose_name='Идентификатор старый')),
                ('deleted_at', models.DateTimeField(blank=True, db_index=True, null=True, verbose_name='Дата мягкого удаления')),
                ('editing', models.BooleanField(default=True, verbose_name='Возможность редактирования')),
                ('deliting', models.BooleanField(default=True, verbose_name='Возможность удаления')),
                ('lastmodified', models.DateTimeField(db_index=True, default=django.utils.timezone.now, editable=False, verbose_name='Последнее обновление')),
                ('item', isc_common.fields.related.ForeignKeyProtect(on_delete=django.db.models.deletion.PROTECT, to='ckk.Item')),
                ('thumb', isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='kd.Documents_thumb')),
                ('thumb10', isc_common.fields.related.ForeignKeyProtect(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='kd.Documents_thumb10')),
            ],
            options={
                'verbose_name': 'Кросс таблица на местоположения графических элементов',
            },
        ),
    ]
